SerialCli

Struct SerialCli 

pub struct SerialCli { /* private fields */ }
Serial Command-line interface.

Implementations

Source

impl SerialCli

pub fn new(port: Box<dyn SerialPort>) -> Self

Create a new SerialCli connected to a SerialPort.

pub fn port(&self) -> &dyn SerialPort

Get reference to underlying SerialPort.

pub fn port_mut(&mut self) -> &mut dyn SerialPort

Get mutable reference to underlying SerialPort.

pub fn start(&mut self) -> Result<()>

Reset serial to prompt.

pub fn send_line(&mut self, line: &str) -> Result<()>

Send line to device.

pub fn send_and_wait_eol(&mut self, line: &str) -> Result<BytesMut>

Send line to device and wait for next end-of-line.

pub fn send_and_wait_prompt(&mut self, line: &str) -> Result<BytesMut>

Send line to device and wait for next CLI prompt.

pub fn read_until_prompt(&mut self) -> Result<BytesMut>

Read until next CLI prompt.

pub fn read_until_ready(&mut self) -> Result<BytesMut>

Read until next CLI “Ready?” prompt.

pub fn read_until_eol(&mut self) -> Result<BytesMut>

Read until next end-of-line.

pub fn consume_response(&mut self) -> Result<String>

Consume command respose, checking for errors.

pub fn get_error(data: &str) -> Option<&str>

Extract error text.